<?php

namespace Assetdocs\Purchaserequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Purchaserequest\Http\Requests\PurchaserequestAdminWebRequest;
use Assetdocs\Purchaserequest\Interfaces\PurchaserequestRepositoryInterface;
use Assetdocs\Purchaserequest\Models\Purchaserequest;

/**
 * Admin web controller class.
 */
class PurchaserequestAdminController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'admin.web';

    /**
     * Initialize purchaserequest controller.
     *
     * @param type PurchaserequestRepositoryInterface $purchaserequest
     *
     * @return type
     */
    public function __construct(PurchaserequestRepositoryInterface $purchaserequest)
    {
        $this->middleware('web');
        $this->middleware('auth:admin.web');
        $this->setupTheme(config('theme.themes.admin.theme'), config('theme.themes.admin.layout'));

        $this->repository = $purchaserequest;
        parent::__construct();
    }

    /**
     * Display a list of purchaserequest.
     *
     * @return Response
     */
    public function index(PurchaserequestAdminWebRequest $request)
    {
        $pageLimit = $request->input('pageLimit');
        if ($request->wantsJson()) {
            $purchaserequests  = $this->repository
            ->pushCriteria(new \Assetdocs\Purchaserequest\Repositories\Criteria\PurchaserequestAdminCriteria())
                ->setPresenter('\\Assetdocs\\Purchaserequest\\Repositories\\Presenter\\PurchaserequestListPresenter')
                ->scopeQuery(function ($query) {
                    return $query->orderBy('id', 'DESC');
                })->paginate($pageLimit);

            $purchaserequests['recordsTotal']    = $purchaserequests['meta']['pagination']['total'];
            $purchaserequests['recordsFiltered'] = $purchaserequests['meta']['pagination']['total'];
            $purchaserequests['request']         = $request->all();
            return response()->json($purchaserequests, 200);

        }

        $this   ->theme->prependTitle(trans('purchaserequest::purchaserequest.names').' :: ');
        return $this->theme->of('purchaserequest::admin.purchaserequest.index')->render();
    }

    /**
     * Display purchaserequest.
     *
     * @param Request $request
     * @param Model   $purchaserequest
     *
     * @return Response
     */
    public function show(PurchaserequestAdminWebRequest $request, Purchaserequest $purchaserequest)
    {
        if (!$purchaserequest->exists) {
            return response()->view('purchaserequest::admin.purchaserequest.new', compact('purchaserequest'));
        }

        Form::populate($purchaserequest);
        return response()->view('purchaserequest::admin.purchaserequest.show', compact('purchaserequest'));
    }

    /**
     * Show the form for creating a new purchaserequest.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PurchaserequestAdminWebRequest $request)
    {

        $purchaserequest = $this->repository->newInstance([]);

        Form::populate($purchaserequest);

        return response()->view('purchaserequest::admin.purchaserequest.create', compact('purchaserequest'));

    }

    /**
     * Create new purchaserequest.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PurchaserequestAdminWebRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.web');
            $purchaserequest          = $this->repository->create($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('purchaserequest::purchaserequest.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/purchaserequest/purchaserequest/'.$purchaserequest->getRouteKey())
            ], 201);


        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
            ], 400);
        }
    }

    /**
     * Show purchaserequest for editing.
     *
     * @param Request $request
     * @param Model   $purchaserequest
     *
     * @return Response
     */
    public function edit(PurchaserequestAdminWebRequest $request, Purchaserequest $purchaserequest)
    {
        Form::populate($purchaserequest);
        return  response()->view('purchaserequest::admin.purchaserequest.edit', compact('purchaserequest'));
    }

    /**
     * Update the purchaserequest.
     *
     * @param Request $request
     * @param Model   $purchaserequest
     *
     * @return Response
     */
    public function update(PurchaserequestAdminWebRequest $request, Purchaserequest $purchaserequest)
    {
        try {

            $attributes = $request->all();

            $purchaserequest->update($attributes);

            return response()->json([
                'message'  => trans('messages.success.updated', ['Module' => trans('purchaserequest::purchaserequest.name')]),
                'code'     => 204,
                'redirect' => trans_url('/admin/purchaserequest/purchaserequest/'.$purchaserequest->getRouteKey())
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/purchaserequest/purchaserequest/'.$purchaserequest->getRouteKey()),
            ], 400);

        }
    }

    /**
     * Remove the purchaserequest.
     *
     * @param Model   $purchaserequest
     *
     * @return Response
     */
    public function destroy(PurchaserequestAdminWebRequest $request, Purchaserequest $purchaserequest)
    {

        try {

            $t = $purchaserequest->delete();

            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('purchaserequest::purchaserequest.name')]),
                'code'     => 202,
                'redirect' => trans_url('/admin/purchaserequest/purchaserequest/0'),
            ], 202);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/purchaserequest/purchaserequest/'.$purchaserequest->getRouteKey()),
            ], 400);
        }
    }
}
