<?php

namespace Assetdocs\Purchaserequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Purchaserequest\Interfaces\PurchaserequestRepositoryInterface;
use Assetdocs\Purchaserequest\Repositories\Presenter\PurchaserequestItemTransformer;

/**
 * Pubic API controller class.
 */
class PurchaserequestApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Purchaserequest\Interfaces\PurchaserequestRepositoryInterface $purchaserequest
     *
     * @return type
     */
    public function __construct(PurchaserequestRepositoryInterface $purchaserequest)
    {
        $this->middleware('api');

        $this->repository = $purchaserequest;
        parent::__construct();
    }

    /**
     * Show purchaserequest's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $purchaserequests = $this->repository
            ->pushCriteria(new \Assetdocs\Purchaserequest\Repositories\Criteria\PurchaserequestPublicCriteria())
            ->setPresenter('\\Assetdocs\\Purchaserequest\\Repositories\\Presenter\\PurchaserequestListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $purchaserequests['code'] = 2000;
        return response()->json($purchaserequests)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show purchaserequest.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $purchaserequest = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($purchaserequest)) {
            $purchaserequest         = $this->itemPresenter($module, new PurchaserequestItemTransformer);
            $purchaserequest['code'] = 2001;
            return response()->json($purchaserequest)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
