<?php

namespace Assetdocs\Purchaserequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Purchaserequest\Http\Requests\PurchaserequestUserApiRequest;
use Assetdocs\Purchaserequest\Interfaces\PurchaserequestRepositoryInterface;
use Assetdocs\Purchaserequest\Models\Purchaserequest;

/**
 * User API controller class.
 */
class PurchaserequestUserApiController extends BaseController
{

    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'api';

    /**
     * Initialize purchaserequest controller.
     *
     * @param type PurchaserequestRepositoryInterface $purchaserequest
     *
     * @return type
     */
    public function __construct(PurchaserequestRepositoryInterface $purchaserequest)
    {
        $this->middleware('api');
        $this->middleware('jwt.auth:api');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $purchaserequest;
        parent::__construct();
    }

    /**
     * Display a list of purchaserequest.
     *
     * @return json
     */
    public function index(PurchaserequestUserApiRequest $request)
    {
        $purchaserequests  = $this->repository
            ->pushCriteria(new \Lavalite\Purchaserequest\Repositories\Criteria\PurchaserequestUserCriteria())
            ->setPresenter('\\Assetdocs\\Purchaserequest\\Repositories\\Presenter\\PurchaserequestListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $purchaserequests['code'] = 2000;
        return response()->json($purchaserequests) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display purchaserequest.
     *
     * @param Request $request
     * @param Model   Purchaserequest
     *
     * @return Json
     */
    public function show(PurchaserequestUserApiRequest $request, Purchaserequest $purchaserequest)
    {

        if ($purchaserequest->exists) {
            $purchaserequest         = $purchaserequest->presenter();
            $purchaserequest['code'] = 2001;
            return response()->json($purchaserequest)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new purchaserequest.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(PurchaserequestUserApiRequest $request, Purchaserequest $purchaserequest)
    {
        $purchaserequest         = $purchaserequest->presenter();
        $purchaserequest['code'] = 2002;
        return response()->json($purchaserequest)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new purchaserequest.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(PurchaserequestUserApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $purchaserequest          = $this->repository->create($attributes);
            $purchaserequest          = $purchaserequest->presenter();
            $purchaserequest['code']  = 2004;

            return response()->json($purchaserequest)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show purchaserequest for editing.
     *
     * @param Request $request
     * @param Model   $purchaserequest
     *
     * @return json
     */
    public function edit(PurchaserequestUserApiRequest $request, Purchaserequest $purchaserequest)
    {
        if ($purchaserequest->exists) {
            $purchaserequest         = $purchaserequest->presenter();
            $purchaserequest['code'] = 2003;
            return response()-> json($purchaserequest)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the purchaserequest.
     *
     * @param Request $request
     * @param Model   $purchaserequest
     *
     * @return json
     */
    public function update(PurchaserequestUserApiRequest $request, Purchaserequest $purchaserequest)
    {
        try {

            $attributes = $request->all();

            $purchaserequest->update($attributes);
            $purchaserequest         = $purchaserequest->presenter();
            $purchaserequest['code'] = 2005;

            return response()->json($purchaserequest)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the purchaserequest.
     *
     * @param Request $request
     * @param Model   $purchaserequest
     *
     * @return json
     */
    public function destroy(PurchaserequestUserApiRequest $request, Purchaserequest $purchaserequest)
    {

        try {

            $t = $purchaserequest->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('purchaserequest::purchaserequest.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
