<?php

namespace Assetdocs\Purchaserequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Purchaserequest\Http\Requests\PurchaserequestUserWebRequest;
use Assetdocs\Purchaserequest\Interfaces\PurchaserequestRepositoryInterface;
use Assetdocs\Purchaserequest\Models\Purchaserequest;

class PurchaserequestUserController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'web';

    /**
     * Initialize purchaserequest controller.
     *
     * @param type PurchaserequestRepositoryInterface $purchaserequest
     *
     * @return type
     */
    public function __construct(PurchaserequestRepositoryInterface $purchaserequest)
    {
        $this->middleware('web');
        $this->middleware('auth:web');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $purchaserequest;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(PurchaserequestUserWebRequest $request)
    {
        $this->repository->pushCriteria(new \Assetdocs\Purchaserequest\Repositories\Criteria\PurchaserequestUserCriteria());
        $purchaserequests = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('purchaserequest::purchaserequest.names').' :: ');

        return $this->theme->of('purchaserequest::user.purchaserequest.index', compact('purchaserequests'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Purchaserequest $purchaserequest
     *
     * @return Response
     */
    public function show(PurchaserequestUserWebRequest $request, Purchaserequest $purchaserequest)
    {
        Form::populate($purchaserequest);

        return $this->theme->of('purchaserequest::user.purchaserequest.show', compact('purchaserequest'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PurchaserequestUserWebRequest $request)
    {

        $purchaserequest = $this->repository->newInstance([]);
        Form::populate($purchaserequest);

        return $this->theme->of('purchaserequest::user.purchaserequest.create', compact('purchaserequest'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PurchaserequestUserWebRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $purchaserequest = $this->repository->create($attributes);

            return redirect(trans_url('/user/purchaserequest/purchaserequest'))
                -> with('message', trans('messages.success.created', ['Module' => trans('purchaserequest::purchaserequest.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Purchaserequest $purchaserequest
     *
     * @return Response
     */
    public function edit(PurchaserequestUserWebRequest $request, Purchaserequest $purchaserequest)
    {

        Form::populate($purchaserequest);

        return $this->theme->of('purchaserequest::user.purchaserequest.edit', compact('purchaserequest'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Purchaserequest $purchaserequest
     *
     * @return Response
     */
    public function update(PurchaserequestUserWebRequest $request, Purchaserequest $purchaserequest)
    {
        try {
            $this->repository->update($request->all(), $purchaserequest->getRouteKey());

            return redirect(trans_url('/user/purchaserequest/purchaserequest'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('purchaserequest::purchaserequest.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(PurchaserequestUserWebRequest $request, Purchaserequest $purchaserequest)
    {
        try {
            $this->repository->delete($purchaserequest->getRouteKey());
            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('purchaserequest::purchaserequest.name')]),
                'code'     => 202,
                'redirect' => trans_url('/user/purchaserequest/purchaserequest/0'),
            ], 202);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
